@@ -144,7 +144,7 @@ class Checker:
                 try:
                     email, password = combo.split(":")
                 except ValueError:
-                    pass
+                    email, password = combo.split(";")
             except queue.Empty:
                 return
 
@@ -182,7 +182,7 @@ class Checker:
             - "custom"
             - "retry"
             - "error"
-            
+
             Failure to do so will raise an error
             '''
 
@@ -196,11 +196,11 @@ class Checker:
             self.print_logo()
             try:
                 proxy_choice = int(input(f'''
- [{self.color}1{RESET}] {self.color}-{RESET} HTTPS
- [{self.color}2{RESET}] {self.color}-{RESET} SOCKS 4
- [{self.color}3{RESET}] {self.color}-{RESET} SOCKS 5
+    [{self.color}1{RESET}] {self.color}-{RESET} HTTPS
+    [{self.color}2{RESET}] {self.color}-{RESET} SOCKS 4
+    [{self.color}3{RESET}] {self.color}-{RESET} SOCKS 5
 
- {self.color}>>{RESET}'''))
+    {self.color}>>{RESET}'''))
             except TypeError:
                 self.run(check)
             self.set_proxy_type(proxy_choice)
@@ -214,21 +214,29 @@ class Checker:
 
         self.print_logo()
         input(f"[{self.color}+{RESET}] {self.color}-{RESET} Press ENTER to start... ")
-        default_threads = threading.active_count()
         self.start_threads()
 
+        q = queue.Queue()
         for line in combo:
-            try:
-                if self.proxy:
-                    proxy = self.get_proxy()
-                else:
-                    proxy = None
-                email, password = line.split(":")
-                thread = threading.Thread(target=check, args=(email, password, proxy))
-                thread.start()
-                if threading.active_count() == thread_count + default_threads:
-                    thread.join()
-            except IndexError:
-                pass
+            q.put_nowait(line)
 
-        input()
+        for _ in range(thread_count):
+            if self.proxy:
+                proxy = self.get_proxy()
+            else:
+                proxy = None
+            threading.Thread(target=self.worker, args=(check, q, proxy)).start()
+
+        '''
+        Your check function must have 3 parameters: email, password and proxy.
+        Whether you use proxies or not the parameter must be present.
+        If you don't use proxies your parameter will have a None type.
+        '''
+
+        q.join()
+        self.cui_thread_status = False
+        for thread in self.threads:
+            thread.join()
+        time.sleep(5)
+        self.print_logo()
+        print(f"[{self.color}+{RESET}] {self.color}-{RESET} Done, you can now close the window...")
